<?php
require_once('path.php');
require_once('base/main_handlers.php');
require_once('lib/util.php');


/**
 * Database maintenance procedure.
 *
 * TODO Test it.
 */
class process_DBCleanup {

    private $config;

    public function __construct(Config $config) {
         $this->config = $config;
    }

    public function run() {
        log_info('DB cleanup started.');
        $dbHandle = new SsoDb();
        self::removeExpiredSessions($dbHandle);
        self::removeDeletedRecords($dbHandle);
        $dbHandle = null;
        log_info('DB cleanup finished.');
    }

    protected function removeExpiredSessions(SsoDb $dbHandle) {
        $sql_stmt = "delete from idp_sessions where expire_time < ?";
        $stmt = $dbHandle->prepare($sql_stmt);
        if (!$stmt) {
            log_error("Can not prepare statement: $sql_stmt");
            return false;
        }
        $stmt->bindValue(1, timeAsString());
        if ($stmt->execute()) {
            log_info("Removed stale idp sessions.");
            $status = true;
        } else {
            log_error("DB error: Can not remove stale idp sessions.");
            $status = false;
        }
        $stmt->closeCursor();
        return $status;
    }

    protected function removeDeletedRecords(SsoDb $dbHandle) {
        // This period determines how long we keep deleted records.
        // TODO (configuration) Make retention period configurable.
        $retention_period = $this->config->keep_deleted_records_for;

        /*
         * It would be nice to obtain this list automatically somehow
         * (either from some registry or from DB metadata)
         */
        $tables = array(
            'sp',
            'sp_user',
            'federation',
            'federation_item',
            'delegation' );
        $cutTime = new DateTime('-' . $retention_period);
        foreach ($tables as $tableName) {
            self::purgeDeletedRecords($dbHandle, $tableName, $cutTime);
        }
    }

    protected function purgeDeletedRecords(SsoDb $dbHandle, $tableName, $cutTime) {
        $sql_stmt = "delete from $tableName where delete_time < ?";
        $stmt = $dbHandle->prepare($sql_stmt);
        if (!$stmt) {
            throw new Exception("Can not prepare statement: $sql_stmt");
        }
        $cutTimeString = $cutTime->format('Y-m-d\TH:i:s\Z');
        $stmt->bindValue(1, $cutTimeString);
        if ($stmt->execute()) {
            log_info("Removed records deleted before $cutTimeString from table $tableName.");
            $status = true;
        } else {
            log_error("DB error: Can not remove deleted recotrds from table $tableName.");
            $status = false;
        }
        $stmt->closeCursor();
        return $status;
    }
}


if ($_SERVER['argc'] > 0) { // If running from command line
    echo "eee ini:", $_SERVER['argv'][1], "\n";
    try {
        require_once('lib/Config.php');
        $default_sso_configuration = new Config($_SERVER['argv'][1]);
        configure_error_handling();
        $worker = new process_DBCleanup($default_sso_configuration);
        $worker->run();
    } catch (Exception $e) {
        log_error("DB cleanup: exception caught at top level {$e->getMessage()}");
        die(1);
    }
}

?>