<?

require_once("testcase_ODB.php");

class FederationTest extends ODBTest {
    public function test_fi(){
        print("Testing Federation Object:\n");
        $fi = new Federation();
        $this->assertIsA($fi, 'Federation');

        $sp = self::create_sp('SP1');
        $user1 = self::create_user($sp->id(), 'User1');
        $user2 = self::create_user($sp->id(), 'User2');

        print("\tcreate FI (add user): ");
        $fi->add_item($user1->id());
        $fi->add_item($user2->id());

        $this->assertNotNull($fi->id());
        $fi_id = $fi->id();
        $match = false;
        foreach ($fi->get_items() as $item) {
            $this->assertIsA($item, 'FederationItem');
        	if($item->user_id() == $user1->id())
        	   $match = true;
        }
        $this->assertTrue($match);
        $this->assertEqual(count($fi->get_items()), 2);

        $fi->save();
        print("ok\n");

        print("\tload_by_sp_user_id FI: ");
        $fi->id(null);
        $fi->load_by_sp_user_id($user1->id());
        $this->assertNotNull($fi->id());
        $this->assertEqual(count($fi->get_items()), 2);
        print("ok\n");

        print("\tset global password: ");
        $fi->set_password('1234');
        $fi->login('Guser1');
        $fi->save();
        print("ok\n");

        print("\tcheck_credentials: ");
        $this->assertTrue($fi->check_credentials('Guser1', '1234'));
        $this->assertFalse($fi->check_credentials('Guser1', '123'));
        $this->assertFalse($fi->check_credentials('Guser2', '1234'));
        print("ok\n");

        print("\tload_by_login FI: ");
        $fi= new Federation();
        $fi->load_by_login('Guser1');
        $this->assertEqual($fi->id(), $fi_id);
        $this->assertEqual(count($fi->get_items()), 2);
        print("ok\n");

        print("done.\n\n");
    }

    public function test_fi_item(){
        print("Testing Federation Item Object:\n");
        $fii = new FederationItem();
        $this->assertIsA($fii, 'FederationItem');

        $sp = self::create_sp('SP1');
        $user1 = self::create_user($sp->id(), 'User1');
        $user2 = self::create_user($sp->id(), 'User2');
        $fi = self::create_fi($user1->id());

        print("\tset_user: ");
        $fii->set_user($user2);
        $fii->fed_id($fi->id());
        $fii->save();
        print("ok\n");

        print("\tload_by_user_id: ");
        $fii->id(null);
        $fii->load_by_user_id($user2->id());
        $this->assertEqual($fii->user_id(), $user2->id());
        $this->assertEqual($fii->fed_id(), $fi->id());
        print("ok\n");

        print("\tget_sp_id: ");
        $this->assertEqual($fii->get_sp_id(), $sp->id());
        print("ok\n");

        print("\tget_sp_login: ");
        $this->assertEqual($fii->get_sp_login(), 'User2');
        print("ok\n");

        $user3 = self::create_user($sp->id(), 'User3');
        print("\tset_user by ID: ");
        $fii->set_user($user3->id());
        $fii->fed_id($fi->id());
        $fii->save();
        $fii->id(null);
        $fii->load_by_user_id($user3->id());
        $this->assertEqual($fii->user_id(), $user3->id());
        print("ok\n");

        print("done.\n\n");
    }
}
?>