
<?
require_once('lib/SAMLSign.php');
require_once('test/testcase_ODB.php');

class SAMLSignTest extends ODBTest {

public function testSign() {
    print("Testing SAML Signature:\n");

    global $default_sso_configuration;
    $sp = self::create_sp('SP1');

    $ass = <<< DOC
    <saml:Assertion
    xmlns:saml="urn:oasis:names:tc:SAML:2.0:assertion"
    Version="2.0"
    ID="123456"
    >
    <saml:Issuer>IDP</saml:Issuer>
    <saml:AuthnStatement
      AuthnInstant="issueInstant"
      SessionIndex="sessionIndex"
      >
      <saml:AuthnContext>
        <saml:AuthnContextClassRef>urn:oasis:names:tc:SAML:2.0:ac:classes:Password</saml:AuthnContextClassRef>
      </saml:AuthnContext>
    </saml:AuthnStatement>
    <saml:Subject>
      <saml:NameID>userSPID</saml:NameID>
    </saml:Subject>
    <saml:AudienceRestriction>
      <saml:Audience>http://xxx.com/1231234qerqr</saml:Audience>
    </saml:AudienceRestriction>
  </saml:Assertion>
DOC;
    $signed = SAMLSign::sign($ass);

    print("\tsign by IdP pkey: ");
    $this->assertPattern('/Signature/',$signed);
    print("ok\n");

    print("\tverify it with IdP cert: ");
    $this->assertTrue(SAMLSign::verify($signed, $default_sso_configuration->cert));
    print("ok\n");

    $ssl = new SslUtils();
    $cert = $ssl->gen_new_cert(array("commonName" => $sp->id()), $sp->id());
    $sp->cert($cert['cert']);
    $sp->save();

    $pkey = $cert['private_key'];

    $ass = <<< DOC
    <saml:Assertion
    xmlns:saml="urn:oasis:names:tc:SAML:2.0:assertion"
    Version="2.0"
    ID="123456"
    >
    <saml:Issuer>{$sp->id()}</saml:Issuer>
    <saml:AuthnStatement
      AuthnInstant="issueInstant"
      SessionIndex="sessionIndex"
      >
      <saml:AuthnContext>
        <saml:AuthnContextClassRef>urn:oasis:names:tc:SAML:2.0:ac:classes:Password</saml:AuthnContextClassRef>
      </saml:AuthnContext>
    </saml:AuthnStatement>
    <saml:Subject>
      <saml:NameID>userSPID</saml:NameID>
    </saml:Subject>
    <saml:AudienceRestriction>
      <saml:Audience>http://xxx.com/1231234qerqr</saml:Audience>
    </saml:AudienceRestriction>
  </saml:Assertion>
DOC;

    print("\tsign by SP pkey: ");
    $signed = SAMLSign::sign($ass, $pkey);
    print("ok\n");

//    print($signed);
    print("\tverify with SP cert: ");
    $this->assertTrue(SAMLSign::verify($signed));
    print("ok\n");
    }
}

?>