<?

require_once("testcase_ODB.php");

class SessionTest extends ODBTest {

    public function test_session(){
        print("Testing Session Object:\n");
        $sp = self::create_sp('SP1');
        $user1 = self::create_user($sp->id(), 'User1');
        $user2 = self::create_user($sp->id(), 'User2');

        $s = new Session();
        $this->assertIsA($s, 'Session');

        print("\tcreate: ");
        $s->create();
        $this->assertTrue($s->id());
        $sid = $s->id();
        $this->assertEqual($s->last_visit(), time());
        $this->assertTrue($s->expire_time());
        $sp_sid1 = $s->add_sp_session($user1);
        $s->save();
        print("ok\n");

        print("\tis_anonymous: ");
        $this->assertTrue($s->is_anonymous());
        $fi = self::create_fi($user1->id());
        $s->load_by_id($s->id());
        $this->assertFalse($s->is_anonymous());
        print("ok\n");

        print("\tis_not_expired: ");
        $this->assertTrue($s->is_not_expired());
        $s->last_visit(time() - 3601);
        $this->assertFalse($s->is_not_expired());
        print("ok\n");

        print("\trenew: ");
        $s->renew();
        $this->assertTrue($s->is_not_expired());
        print("ok\n");

        print("\tadd_session: ");
        $sp_sid2 = $s->add_sp_session($user2->id());
        $s->save();
        $this->assertEqual(count($s->get_sp_sessions()), 2);
        print("ok\n");

        print("\tclose_session: ");
        $s->close_sp_session($sp_sid1);
        $this->assertEqual(count($s->get_sp_sessions()), 1);
        print("ok\n");

        print("\tload_by_sp_session not exist: ");
        $s->load_by_sp_session($sp_sid1);
        $this->assertFalse($s->id());
        print("ok\n");

        print("\tload_by_sp_session exist: ");
        $s->load_by_sp_session($sp_sid2);
        $this->assertEqual($s->id(), $sid);
        $this->assertEqual(count($s->get_sp_sessions()), 1);
        $this->assertTrue($s->is_anonymous());
        print("ok\n");

        print("done.\n\n");

    }
    public function test_sp_session(){
        print("Testing SpSession Object:\n");
        $sp = self::create_sp('SP1');
        $user1 = self::create_user($sp->id(), 'User1');
        $session = self::create_session($user1);

        $s = new SpSession();
        $this->assertIsA($s, 'SpSession');

        print("\tcreate: ");
        $s->set_user($user1);
        $s->id(SpSession::make_new_id());
        $ssid = $s->id();
        $s->session_id($session->id());
        $s->save();
        print("ok\n");

        print("\tload: ");
        $s->load_by_id($ssid);
        $this->assertEqual($s->id(), $ssid);
        print("ok\n");

        print("\t_user: ");
        $this->assertIsA($s->get_user(), 'SpUser');
        $this->assertEqual($s->get_login(), 'User1');
        $this->assertEqual($s->get_sp_id(), $sp->id());
        $this->assertFalse($s->get_fed_id());
        print("ok\n");

        print("done.\n\n");
    }
}

?>