<?

require_once("testcase_ODB.php");

class SimpleObjectTest extends ODBTest {
    private function _test_new(){
        $obj = new SimpleObject();
        $this->assertIsA($obj, 'SimpleObject');
        $this->assertNull($obj->id());
    }

    private function _test_save(){
        $obj = new SimpleObject();
        $id = $obj->make_new_id();
        $this->assertNotNull($id);
        $obj->id($id);
        $obj->value('test');
        $obj->save();
        $this->assertEqual($obj->id(), $id);
        return $obj->id();
    }

    private function _test_load($id){
        $obj = new SimpleObject($id);
        $this->assertEqual($obj->id(), $id);
        $this->assertEqual($obj->value(), 'test');
    }

    private function _test_load_by_id($id){
        $obj = new SimpleObject();
        $obj->load_by_id($id);
        $this->assertEqual($obj->id(), $id);
        $this->assertEqual($obj->value(), 'test');
    }
    private function _test_filter($id){
        $obj = new SimpleObject();
        $obj->id($obj->make_new_id());
        $obj->value('test');
        $obj->save();

        $list = $obj->filter(array('obj_id' => $id));
        $this->assertEqual(count($list), 1);
        $this->assertEqual($list[0]->id(), $id);

        $list = $obj->filter(array('value' => 'test'));
        $this->assertEqual(count($list), 2);

        $list = $obj->filter(array('obj_id' => 'stuff123'));
        $this->assertEqual(count($list), 0);
    }
    private function _test_delete($id){
        $obj = new SimpleObject($id);
        $obj->delete();
        $obj->id(null);
        $obj->load_by_id($id);
        $this->assertNull($obj->id());
    }

    public function test_all(){
        print("Testing Simple Object (ODB features):\n");
        print("\t__construct(): ");
        $this->_test_new();
        print("ok\n");
        print("\tsave(): ");
        $id = $this->_test_save();
        print("ok\n");
        print("\tload(): ");
        $this->_test_load($id);
        print("ok\n");
        print("\tload_by_id(): ");
        $this->_test_load_by_id($id);
        print("ok\n");
        print("\tfilter(): ");
        $this->_test_filter($id);
        print("ok\n");
        print("\tdelete(): ");
        $this->_test_delete($id);
        print("ok\n");
        print("done.\n\n");
    }
}

class SimpleObject extends AbstractObject {
    protected $_props = array(
    	'obj_id' => NULL,
	    'value' => NULL,
	    'delete_time' => NULL
    );
    protected $_table = array(
    	'tbl_id' => 'obj_id',
	    'tbl_name' => 'odb_test'
    );
}

?>