<?php

require_once("testcase_header.php");

require_once("lib/SimpleObjectStorage.php");
require_once("lib/Session.php");
require_once("lib/util.php");

class test_Object {

    public $id;

    public $value;

    public function __construct($id, $value) {
        $this->id = $id;
        $this->value = $value;
    }
}


class test_lib_SimpleObjectStorageTest extends UnitTestCase {

	private $base_path = "/tmp/sso_testing/sessions";

	private $reporter;

	public function __construct($reporter) {
        $this->reporter = $reporter;
	}

	public function setUp() {
		rmdir_r($this->base_path);
		mkdir($this->base_path, 0777, true);
		$this->assertTrue(is_readable($this->base_path), "Can not create " . $this->base_path);
	}

	public function tearDown() {
		rmdir_r($this->base_path);
	}

	public function testSimple() {
		$storage = new lib_SimpleObjectStorage($this->base_path);
		$session = new test_Object(33, "Random Homeland");

		$this->assertNull($storage->lookup($session->id));
		$storage->store($session->id, $session); // No exceptions expected
		$restored_session = $storage->lookup($session->id);
		$this->assertIsA($restored_session, "test_Object");
		$this->assertEqual($restored_session->id, $session->id);
		$storage->erase($session->id);
		$this->assertNull($storage->lookup($session->id));
	}

	public function testDoubleErase() {
		$storage = new lib_SimpleObjectStorage($this->base_path);
		$session = new test_Object('quelque', "Random Homeland");

		$storage->store($session->id, $session); // No exceptions expected
		$storage->erase($session->id);
		try {
			$storage->erase($session->id);
		} catch (Exception $e) {
			$this->assertEqual($e->getCode(), 500);
		}
	}

	public function testNoAccess() {
		$storage = new lib_SimpleObjectStorage("/tmp/kljh1234lkjh2134kjlhamnsdfnmbxzlciuvxzcvewiourtasbhuih ");
		try {
		    $id = 'kilo_byte-you';
			$storage->store($id, new test_Object($id, "Random Homeland"));
			$this->fail("Exception expected.");
		} catch (Exception $e) {
			// Expected
		}
	}


	/**
	 * Simple performance test.
	 * Previous results:
	 * <ul>
	 * <li>count=10000 and less : ~0.6 msec/object
	 * <li>count=100000 : ~8.5 msec/object
	 * </ul>
	 */
	public function testPerformance() {
	    assert('!is_null($this->reporter)');

	    // This test takes some time so it is disabled by default.
	    $this->reporter->paintFormattedMessage(
            "Storage performance test skipped.");
        return;

    	$storage = new lib_SimpleObjectStorage($this->base_path);
    	$ids = array();

    	$count = 2000;
        $time_a = microtime(true);
    	// populate
    	for ($i = 0; $i < $count; ++$i) {
        	$id = make_new_id();
    		array_push($ids, $id);
            $storage->store($id, new test_Object($id, "Bubble boobs"));
    	}
    	// do lookups
    	shuffle($ids);
    	foreach ($ids as $id) {
    		$storage->lookup($id);
    	}
    	// cleanup
    	foreach ($ids as $id) {
    	    $storage->erase($id);
    	}
    	$time_b = microtime(true);
    	$elapsed = ($time_b - $time_a);
        $this->reporter->paintFormattedMessage(
            "Storage performance test took " . $elapsed . " (" . (1000 * $elapsed / $count) . " msec/cycle)");
	}

}

// $reporter = new TextReporter();
// $test = new lib_SimpleObjectStorageTest($reporter);
// $test->run($reporter);

?>