<?
require_once("toy_service.php");
require_once("lib/ODB.php");
require_once("lib/Delegation.php");
require_once("lib/Federation.php");
require_once("lib/Config.php");
require_once("lib/SpUser.php");
require_once("lib/SslUtils.php");


class ODBTest extends UnitTestCase {

    private $_dirname = null;
    private $_sql_create = "CREATE TABLE IF NOT EXISTS odb_test (obj_id text PRIMARY KEY, value text not null, delete_time NUMERIC default NULL)";


    public function __construct(){
        global $default_sso_configuration;
        $this->_dirname = dirname(__FILE__);
        $this->_dbdirname = $this->_dirname.'/tmp';
        $default_sso_configuration->db_file = "$this->_dbdirname/test.db";
    }

    public function setUp() {
        global $default_sso_configuration;
        $dbdirname = $this->_dbdirname;
        if (!is_writable($dbdirname)) {
            mkdir($dbdirname, 0777);
        }

        system("sqlite3 $default_sso_configuration->db_file < $this->_dirname/db-schema-1.sql");

        $dbh = new SsoDb();
        $sth = $dbh->prepare($this->_sql_create);
        if (!$sth) {
            throw new Exception('Testcase error. Can not prepare statement '. $this->_sql_create);
        }
        $sth->execute();
    }

    public function tearDown() {
        global $default_sso_configuration;
        unlink($default_sso_configuration->db_file);
    }

    public static function create_sp($name){
        $sp = new Sp();
        $sp->id(make_new_id());
        $sp->name($name);
        $ssl = new SslUtils();
        $cert = $ssl->gen_new_cert(array("commonName" => $sp->id()), $sp->id());
        $sp->cert($cert["cert"]);
        $sp->idp_id('123');
        $sp->api_version('1.0');
        $sp->api_url('/');
        $sp->save();
        return $sp;
    }

    /**
     * @return Federation
     */
    public static function create_fi($user_id, $login = null, $passwd = null){
        $fi = new Federation();
        $fi->add_item($user_id);
        if($login){
            $fi->login($login);
            $fi->set_password($passwd);
        }
        $fi->save();
        return $fi;
    }

    public static function create_user($sp_id, $sp_login){
        $user = new SpUser();
        $user->id($user->make_new_id());
        $user->sp_id($sp_id);
        $user->sp_login($sp_login);
        $user->save();
        return $user;
    }

    public static function create_session($user_id){
        $s = new Session();
        $s->create();
        $s->add_sp_session($user_id);
        $s->save();
        return $s;
    }

    public static function create_delegation($src_user_id, $dst_user_id){
        $del = new Delegation();
        $del->src_user($src_user_id);
        $del->dst_user($dst_user_id);
        $del->save();
        return $del;
    }

}


?>